"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const react_native_1 = require("react-native");
const useDimensions_1 = __importDefault(require("./hooks/useDimensions"));
const useRenderRow_1 = __importDefault(require("./hooks/useRenderRow"));
const useRows_1 = __importDefault(require("./hooks/useRows"));
const utils_1 = require("./utils");
const SimpleGrid = (0, react_1.forwardRef)((props, ref) => {
    const { style = {}, spacing = 10, fixed = false, data, itemDimension = 120, renderItem, horizontal = false, additionalRowStyle: externalRowStyle, itemContainerStyle, keyExtractor: customKeyExtractor = null, invertedRow = false, onItemsPerRowChange, ...restProps } = {
        onLayout: null,
        listKey: undefined,
        adjustGridToStyles: false,
        ...props,
    };
    const { onLayout, itemsPerRow, containerDimension, fixedSpacing } = (0, useDimensions_1.default)(props);
    const { containerStyle, containerFullWidthStyle, rowStyle } = (0, react_1.useMemo)(() => (0, utils_1.generateStyles)({
        horizontal,
        itemDimension,
        containerDimension,
        spacing,
        fixedSpacing,
        fixed,
        itemsPerRow,
    }), [horizontal, itemDimension, containerDimension, itemsPerRow, spacing, fixedSpacing, fixed]);
    const { rows, keyExtractor } = (0, useRows_1.default)({
        data,
        invertedRow,
        itemsPerRow,
        keyExtractor: customKeyExtractor,
        onItemsPerRowChange,
    });
    const renderRow = (0, useRenderRow_1.default)({
        renderItem,
        spacing,
        keyExtractor: customKeyExtractor,
        externalRowStyle,
        itemContainerStyle,
        horizontal,
        invertedRow,
    });
    return (<react_native_1.View style={[
            {
                ...(horizontal ? { paddingLeft: spacing } : { paddingTop: spacing }),
            },
            style,
        ]} ref={ref} {...restProps}>
      {rows.map((row, index) => (<react_native_1.View key={keyExtractor(row, index)} onLayout={onLayout}>
          {renderRow({
                rowItems: row,
                rowIndex: index,
                isLastRow: index === rows.length - 1,
                itemsPerRow,
                rowStyle,
                containerStyle,
                containerFullWidthStyle,
                separators: null,
            })}
        </react_native_1.View>))}
    </react_native_1.View>);
});
exports.default = (0, react_1.memo)(SimpleGrid);
