"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const react_native_1 = require("react-native");
function useRenderRow({ renderItem, spacing, keyExtractor, externalRowStyle, itemContainerStyle, horizontal, invertedRow, }) {
    return (0, react_1.useCallback)(({ rowItems, rowIndex, separators, isLastRow, itemsPerRow, rowStyle, containerStyle, containerFullWidthStyle, }) => {
        // To make up for the top padding
        const additionalRowStyle = isLastRow
            ? {
                [horizontal ? 'marginRight' : 'marginBottom']: spacing,
            }
            : {};
        const hasFullWidthItem = !!rowItems.find((i) => i._fullWidth);
        return (<react_native_1.View style={[rowStyle, additionalRowStyle, externalRowStyle, hasFullWidthItem ? { flexDirection: 'column', paddingBottom: 0 } : {}]}>
          {rowItems.map((item, index) => {
                const i = invertedRow ? -index + itemsPerRow - 1 : index;
                return (<react_native_1.View key={keyExtractor ? keyExtractor(item, rowIndex * itemsPerRow + i) : `item_${rowIndex * itemsPerRow + i}`} style={[item._fullWidth ? containerFullWidthStyle : containerStyle, itemContainerStyle]}>
                {renderItem({
                        item,
                        index: rowIndex * itemsPerRow + i,
                        separators,
                        rowIndex,
                    })}
              </react_native_1.View>);
            })}
        </react_native_1.View>);
    }, [renderItem, spacing, keyExtractor, externalRowStyle, itemContainerStyle, horizontal, invertedRow]);
}
exports.default = useRenderRow;
