import { type StyleProp, type ViewStyle } from 'react-native';
declare function chunkArray<T extends {
    _fullWidth?: number;
}>(array: T[], size: number): T[][];
declare function calculateDimensions({ itemDimension, staticDimension, totalDimension, fixed, spacing, maxItemsPerRow }: {
    itemDimension: any;
    staticDimension: any;
    totalDimension: any;
    fixed: any;
    spacing: any;
    maxItemsPerRow: any;
}): {
    itemTotalDimension: number;
    availableDimension: number;
    itemsPerRow: number;
    containerDimension: number;
    fixedSpacing: number;
};
declare function getAdjustedTotalDimensions({ totalDimension, maxDimension, contentContainerStyle, style, horizontal, adjustGridToStyles }: {
    totalDimension: any;
    maxDimension: any;
    contentContainerStyle: any;
    style: any;
    horizontal?: boolean;
    adjustGridToStyles?: boolean;
}): any;
declare function generateStyles({ itemDimension, containerDimension, spacing, fixed, horizontal, fixedSpacing, itemsPerRow, }: {
    itemDimension: any;
    containerDimension: any;
    spacing: number;
    fixed: boolean;
    horizontal?: boolean;
    fixedSpacing: number;
    itemsPerRow: number;
}): {
    containerFullWidthStyle: ViewStyle;
    containerStyle: ViewStyle;
    rowStyle: ViewStyle;
};
export { calculateDimensions, chunkArray, generateStyles, getAdjustedTotalDimensions };
export type CommonProps<ItemType> = {
    /**
     * Additional styles for rows (rows render multiple items within), apart from the generated ones.
     */
    additionalRowStyle?: StyleProp<ViewStyle>;
    /**
     * Minimum width or height for each item in pixels (virtual).
     */
    itemDimension?: number;
    /**
     * If true, the exact itemDimension will be used and won't be adjusted to fit the screen.
     */
    fixed?: boolean;
    /**
     * Spacing between each item.
     */
    spacing?: number;
    /**
     * Specifies a static width or height for the GridView container.
     * If your container dimension is known or can be calculated at runtime
     * (via Dimensions.get('window'), for example), passing this prop will force the grid container
     * to that dimension size and avoid the reflow associated with dynamically calculating it
     */
    staticDimension?: number;
    /**
     * Specifies a maximum width or height for the container. If not passed, full width/height
     * of the screen will be used.
     */
    maxDimension?: number;
    /**
     * Specifies the style about content row view
     */
    itemContainerStyle?: StyleProp<ViewStyle>;
    /**
     * Reverses the direction of each row item. It can be used with the [`inverted`](https://reactnative.dev/docs/flatlist#inverted) property.
     * ex) [0, 1, 2] -> [2, 1, 0]
     */
    invertedRow?: boolean;
    /**
     * Specifies the maximum items to render per row
     */
    maxItemsPerRow?: number;
    /**
     * When set to true the library will calculate the total dimensions taking into account padding in style prop, and padding + maxWidth/maxHeight in contentContainerStyle prop
     */
    adjustGridToStyles?: boolean;
    /**
     * When number of items per row is determined, this callback is called.
     * @param itemsPerRow Number of items per row
     */
    onItemsPerRowChange?: (itemsPerRow: number) => void;
};
